@@ -14,5 +14,8 @@ use Sub::Exporter -setup => {
 
 require Judy; # Beware, Judy.pm also loads Judy::L.
 
+require Judy::L::_tie;
+require Judy::L::_obj;
+
 no warnings;
 'Warning! The consumption of alcohol may cause you to think you have mystical kung-fu powers.'
